﻿checkRequire("Lua_MailItem")
Lua_MailPanel = class("Lua_MailPanel", Lua_DisplayObject);
function Lua_MailPanel:ctor(p)
	self:superCall("ctor", p, "MailPanel_skin");    
end

function Lua_MailPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.mailList = Lua_DragList.new(self.content,1, Vector4(0, 0, 346, 513));
	self.mailList:setListCell(Lua_MailItem, 115, 346, 1);
	self.mailList:setLocation(-430, 8, 0);

	self.adjunctList = Lua_DragList.new(self.content, 2, Vector4(0, 0, 562, 90));
	self.adjunctList:setListCell(Lua_MailRewardsItem, 90, 90, 1000);
	self.adjunctList:setLocation(150, -190, 0);

	self.dragContainer = Lua_DragContainer.new(self.content, 1, Vector4(315, -135, 630, 270));
	self.dragContainer:setLocation(-175, 145, 0);
	self.mailInfoPanel = Lua_MailInfoPanel.new(self.dragContainer);
	self.dragContainer:addSubContainer(self.mailInfoPanel, true);

	if DataCenter.mailData.mailInfoArr:getSize() > 0 then
		self:setSelected(DataCenter.mailData.mailInfoArr[1]);
	end

	self.delReadedBtn:addClickFuntion(self, self.onDeletedClick);
	self.drawAllBtn:addClickFuntion(self, self.onOneGetClick);
	self.deleteBtn:addClickFuntion(self, self.onDeleteClick);
	self.drawBtn:addClickFuntion(self, self.onGetClick);

	self:addLuaEvent("MAIL_CELL_CLICK", self, self.setSelected);
	self:addLuaEvent("UPDATE_MAIL_DATA", self, self.updateMailPanelInfo);
	self:addLuaEvent("MAIL_INFOMATION", self, self.showMailInfo);
	self:addLuaEvent("SETENABLE_FALSE", self, self.setEnableOfBtn);
	DataCenter.mailData:sMailList();
end

function Lua_MailPanel:setSelected(val)
	local mailInfoArr = DataCenter.mailData.mailInfoArr;
	for i = 1, mailInfoArr:getSize() do
		mailInfoArr[i].selected = mailInfoArr[i].mail_id == val.mail_id; 
	end
	self.mailList:setLuaArrayData(mailInfoArr);

	self.selectedMailId = val.mail_id;
	DataCenter.mailData:sMailInfo(val.mail_id);
end

function Lua_MailPanel:updateMailPanelInfo()
	local isEnable = DataCenter.mailData.deposit_mail_amount ~= 0;
	self.delReadedBtn:setBtnEnable(isEnable);
	self.drawAllBtn:setBtnEnable(isEnable);
	self.deleteBtn:setBtnEnable(isEnable);
	self.drawBtn:setBtnEnable(isEnable);

	local mailInfoArr = DataCenter.mailData.mailInfoArr;
	if self.selectedMailId ~= 0 then
		local curMailData = DataCenter.mailData:getMailByMailId(self.selectedMailId);
		if curMailData ~= nil then
			self:setSelected(curMailData);
		else
			if mailInfoArr:getSize() > 0 then
				self:setSelected(mailInfoArr[1]);
			else
				self:showMailInfo(nil);
				self.mailList:setLuaArrayData(mailInfoArr);
			end
		end
	end

	for i = 1, mailInfoArr:getSize() do
		if mailInfoArr[i].has_attach == 1 then
			self.drawAllBtn:setBtnEnable(true);
			break;
		else
			self.drawAllBtn:setBtnEnable(false);
		end
	end
end

function Lua_MailPanel:showMailInfo(msg)
	self.data = msg;
	if msg == nil then
		self.senderTxt.text = "";
		self.titleTxt.text = "";
		self.drawBtn:setBtnEnable(false);
		self.mailInfoPanel:showMailContent();
	else
		local curMailData = DataCenter.mailData:getMailByMailId(msg.mail_id);
		curMailData.has_read = 1;
		self.mailList:setLuaArrayData(DataCenter.mailData.mailInfoArr);

		self.senderTxt.text = msg.role_name;
		self.titleTxt.text = msg.mail_title;
		self.drawBtn:setBtnEnable(curMailData.has_attach == 1);
		self.mailInfoPanel:showMailContent(msg.mail_content);

		if curMailData.has_attach == 1 and DataCenter.mailData.adjunctInfoArr ~= nil then
			self.adjunctList:setLuaArrayData(DataCenter.mailData.adjunctInfoArr);
			self.adjunctList:setEnable(true);
		else
			self.adjunctList:setEnable(false);
		end

		local gt = tonumber(tostring(msg.get_time));
		if gt <= 0 then
			self.timeLab.text = "";
			Lua_CommonUtil.removeTimer(self, self.onCountDown);
		else
			self.startTime = getTime();
			self:addTimer("Lua_MailPanel", 0.5, self, self.onCountDown);
			self:onCountDown();
		end
	end
	self.dragContainer:updateChildPos();
end

function Lua_MailPanel:onCountDown()
	if self.data == nil then
		return;
	end

	local time = self.data.left_get_time - (getTime() - self.startTime);
	if time < 0 then
		time = 0;
		Lua_CommonUtil.removeTimer(self, self.onCountDown);
	else
		time = math.floor(time);
	end
	self.timeLab.text = LanUtil.formateStr(LanUtil.getValue(110059), TimeTransform.getInstance():transSeconds6(time, true, true));
end

function Lua_MailPanel:setEnableOfBtn(val)
	self.drawAllBtn:setBtnEnable(val);
end

function Lua_MailPanel:onDeletedClick(go)
	local mailInfoArr = DataCenter.mailData.mailInfoArr;
	local arr = Array();
	local showTip = 0;
	for i = 1, mailInfoArr:getSize() do
		if mailInfoArr[i].has_read == 1 and mailInfoArr[i].has_attach == 0 then
			arr:add(mailInfoArr[i].mail_id);
		elseif mailInfoArr[i].has_attach == 1 then
			if mailInfoArr[i].get_time ~= 0 and mailInfoArr[i].leftTime <= 0 then
				arr:add(mailInfoArr[i].mail_id);
			else
				if showTip == 0 then
					OperateAlert.show(LanUtil.getValue(110057));
					showTip = 1;
				end
			end
		elseif mailInfoArr[i].has_read == 0 then
			-- OperateAlert.show(LanUtil.getValue(110058));
		end
	end

	if arr:getSize() > 0 then
		DataCenter.mailData:sDeleteMails(2, arr);
	end
end

function Lua_MailPanel:onOneGetClick(go)
	DataCenter.mailData:sGetAllAdjunct();
end

function Lua_MailPanel:onDeleteClick(go)
	if self.data == nil then
		return;
	end

	local curMailData = DataCenter.mailData:getMailByMailId(self.data.mail_id);
	if curMailData == nil then
		return;
	end

	if curMailData.has_attach == 0 then
		DataCenter.mailData:sDeleteMail(3, self.data.mail_id);
	else
		if curMailData.get_time ~= 0 and curMailData.leftTime <= 0 then
			DataCenter.mailData:sDeleteMail(3, self.data.mail_id);
		else
			OperateAlert.show(LanUtil.getValue(110057));
		end
	end
end

function Lua_MailPanel:onGetClick(go)
	if self.data == nil then
		return;
	end

	local curMailData = DataCenter.mailData:getMailByMailId(self.data.mail_id);
	if curMailData ~= nil and curMailData.has_attach == 1 then
		DataCenter.mailData:sMailAdjunct(self.data.mail_id);
	end
end

function Lua_MailPanel:dispose()
	if self.mailList ~= nil then
		self.mailList:dispose();
		self.mailList = nil;
	end
	if self.adjunctList ~= nil then
		self.adjunctList:dispose();
		self.adjunctList = nil;
	end
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	if self.mailInfoPanel ~= nil then
		self.mailInfoPanel:dispose();
		self.mailInfoPanel = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_MailInfoPanel = class("Lua_MailInfoPanel", Lua_DragContainerItem);
function Lua_MailInfoPanel:ctor(dragContainer)
	self:superCall("ctor", dragContainer.sub, "MailDesTxt_skin");
	self.dragContainer = dragContainer;
end

function Lua_MailInfoPanel:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_MailInfoPanel:getHeight()
	return self.desTxt.height;
end

function Lua_MailInfoPanel:onPlayerSoundClick()
	self:superCall("onPlayerSoundClick");

	local urlStr = self.desTxt:getUrlByMousePos();
	if urlStr ~= nil then
		Lua_ChatUtil.urlClickHandle(urlStr);
	end
end

function Lua_MailInfoPanel:showMailContent(descStr)
	if descStr ~= nil then
		self.desTxt.text = descStr;
	else
		self.desTxt.text = "";
	end
	self.dragContainer.canDrag = self.desTxt.height > self.dragContainer.vsize.w;
end





--------------------------------------------------





Lua_MailRewardsItem = class("Lua_MailRewardsItem", Lua_ListCell)
function Lua_MailRewardsItem:ctor(p)
	self:superCall("ctor", p, "MailRewardItem_skin");
end

function Lua_MailRewardsItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
	self.itemImg:setDepth(6);
	self.itemImg:setEnable(false);
	self.itemImg:setCanClick(false);
end

function Lua_MailRewardsItem:setData(data)
	self._data = data;

	if data ~= nil then
		local tvo = Lua_ToolVo.createToolVo(data.id);
		tvo:fromServer(data);
		if tvo.subType == Lua_PackTypeDefine.CARD_ITEM then
			tvo.packType = 999;
		end
		self.itemImg.data = tvo;
		self.itemImg:showNumFromNumberOne(data.amount, true);
		self.itemImg:setEnable(true);
	else
		self.itemImg:setEnable(false);
	end
end

function Lua_MailRewardsItem:onPlayerSoundClick(go)
	Lua_PackUtil.showItemInfo(self.itemImg.data, false, false, self.itemImg.isShowBtns);
end

function Lua_MailRewardsItem:dispose()
	if self.itemImg ~= nil then
		self.itemImg:dispose();
		self.itemImg = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end